<?php

/**
 * @defgroup api_v1_users User API requests
 */

/**
 * @file api/v1/users/index.php
 *
 * Copyright (c) 2014-2021 Simon Fraser University
 * Copyright (c) 2003-2021 John Willinsky
 * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
 *
 * @ingroup api_v1_users
 *
 * @brief Handle requests for user API functions.
 *
 */

return new \APP\API\v1\users\UserHandler();
